/*
 * Copyright (C) 2016 Canonical Ltd.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2 or version 3 of the License.
 * See http://www.gnu.org/copyleft/lgpl.html the full text of the license.
 */

#ifndef __SNAPD_GLIB_H__
#define __SNAPD_GLIB_H__

#define __SNAPD_GLIB_INSIDE__

#include <snapd-glib/snapd-alias.h>
#include <snapd-glib/snapd-app.h>
#include <snapd-glib/snapd-assertion.h>
#include <snapd-glib/snapd-auth-data.h>
#include <snapd-glib/snapd-category-details.h>
#include <snapd-glib/snapd-category.h>
#include <snapd-glib/snapd-channel.h>
#include <snapd-glib/snapd-client.h>
#include <snapd-glib/snapd-connection.h>
#include <snapd-glib/snapd-enum-types.h>
#include <snapd-glib/snapd-error.h>
#include <snapd-glib/snapd-icon.h>
#include <snapd-glib/snapd-interface.h>
#include <snapd-glib/snapd-link.h>
#include <snapd-glib/snapd-log.h>
#include <snapd-glib/snapd-login.h>
#include <snapd-glib/snapd-maintenance.h>
#include <snapd-glib/snapd-markdown-node.h>
#include <snapd-glib/snapd-markdown-parser.h>
#include <snapd-glib/snapd-media.h>
#include <snapd-glib/snapd-notices-monitor.h>
#include <snapd-glib/snapd-plug-ref.h>
#include <snapd-glib/snapd-plug.h>
#include <snapd-glib/snapd-price.h>
#include <snapd-glib/snapd-screenshot.h>
#include <snapd-glib/snapd-slot-ref.h>
#include <snapd-glib/snapd-slot.h>
#include <snapd-glib/snapd-snap.h>
#include <snapd-glib/snapd-system-information.h>
#include <snapd-glib/snapd-task.h>
#include <snapd-glib/snapd-user-information.h>
#include <snapd-glib/snapd-version.h>

#undef __SNAPD_GLIB_INSIDE__

#endif /* __SNAPD_GLIB_H__ */
