
/* This file is generated by glib-mkenums, do not modify it. This code is licensed under the same license as the containing project. Note that it links to GLib, so must comply with the LGPL linking clauses. */

/*
 * Copyright (C) 2016 Canonical Ltd.
 *
 * This library is free software; you can redistribute it and/or modify it under
 * the terms of the GNU Lesser General Public License as published by the Free
 * Software Foundation; either version 2 or version 3 of the License.
 * See http://www.gnu.org/copyleft/lgpl.html the full text of the license.
 */

#ifndef __SNAPD_ENUM_TYPES_H__
#define __SNAPD_ENUM_TYPES_H__

#if !defined(__SNAPD_GLIB_INSIDE__) && !defined(SNAPD_COMPILATION)
#error "Only <snapd-glib/snapd-glib.h> can be included directly."
#endif

#include <glib-object.h>

G_BEGIN_DECLS
/* enumerations from "snapd-alias.h" */
GType snapd_alias_status_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_ALIAS_STATUS (snapd_alias_status_get_type())
/* enumerations from "snapd-app.h" */
GType snapd_daemon_type_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_DAEMON_TYPE (snapd_daemon_type_get_type())
/* enumerations from "snapd-channel.h" */
GType snapd_confinement_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_CONFINEMENT (snapd_confinement_get_type())
/* enumerations from "snapd-client.h" */
GType snapd_change_filter_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_CHANGE_FILTER (snapd_change_filter_get_type())
GType snapd_get_snaps_flags_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_GET_SNAPS_FLAGS (snapd_get_snaps_flags_get_type())
GType snapd_get_apps_flags_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_GET_APPS_FLAGS (snapd_get_apps_flags_get_type())
GType snapd_get_connections_flags_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_GET_CONNECTIONS_FLAGS (snapd_get_connections_flags_get_type())
GType snapd_find_flags_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_FIND_FLAGS (snapd_find_flags_get_type())
GType snapd_install_flags_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_INSTALL_FLAGS (snapd_install_flags_get_type())
GType snapd_remove_flags_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_REMOVE_FLAGS (snapd_remove_flags_get_type())
GType snapd_create_user_flags_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_CREATE_USER_FLAGS (snapd_create_user_flags_get_type())
GType snapd_get_interfaces_flags_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_GET_INTERFACES_FLAGS (snapd_get_interfaces_flags_get_type())
GType snapd_theme_status_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_THEME_STATUS (snapd_theme_status_get_type())
/* enumerations from "snapd-error.h" */
GType snapd_error_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_ERROR (snapd_error_get_type())
/* enumerations from "snapd-maintenance.h" */
GType snapd_maintenance_kind_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_MAINTENANCE_KIND (snapd_maintenance_kind_get_type())
/* enumerations from "snapd-markdown-node.h" */
GType snapd_markdown_node_type_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_MARKDOWN_NODE_TYPE (snapd_markdown_node_type_get_type())
/* enumerations from "snapd-notice.h" */
GType snapd_notice_type_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_NOTICE_TYPE (snapd_notice_type_get_type())
/* enumerations from "snapd-snap.h" */
GType snapd_snap_type_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_SNAP_TYPE (snapd_snap_type_get_type())
GType snapd_snap_status_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_SNAP_STATUS (snapd_snap_status_get_type())
GType snapd_publisher_validation_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_PUBLISHER_VALIDATION (snapd_publisher_validation_get_type())
/* enumerations from "snapd-system-information.h" */
GType snapd_system_confinement_get_type (void) G_GNUC_CONST;
#define SNAPD_TYPE_SYSTEM_CONFINEMENT (snapd_system_confinement_get_type())
G_END_DECLS

#endif /* !__SNAPD_ENUM_TYPES_H__ */

/* Generated data ends here */

